@@ -23,7 +23,7 @@
 #' @param method Optional: Specify one or more of the [optimx::optimx()] methods
 #'   for which to calculate BICs. If NULL (the default),
 #'   log-likelihoods will be returned for all of the methods in
-#'   `obj$settings_optimx$method`.
+#'   `obj$pk_settings$optimx$method`.
 #' @param exclude Logical: `TRUE` to compute the AIC after removing any
 #'   observations in the data marked for exclusion (if there is a variable
 #'   `exclude` in the data, an observation is marked for exclusion when `exclude
@@ -52,7 +52,7 @@ BIC.pk <- function(object,
     stop(attr(check, "msg"))
   }
   if (is.null(model)) model <- names(object$stat_model)
-  if (is.null(method)) method <- object$settings_optimx$method
+  if (is.null(method)) method <- object$pk_settings$optimx$method
 
   # get log-likelihoods
   ll <- logLik(object = object,
@@ -65,30 +65,31 @@ BIC.pk <- function(object,
                drop_obs = FALSE)
 
 
+  data_grp <- get_data_group.pk(object)
+  data_grp_vars <- get_data_group.pk(object, as_character = TRUE)
+
   # obj$fit is a "long" data.frame with both parameters and sigma values
-  params_df <- object$fit %>%
-    dplyr::filter(optimize_param == TRUE) %>%
-    group_by(!!!object$data_group, model, method) %>%
+  params_df <- object$fit |>
+    dplyr::filter(optimize_param == TRUE) |>
+    group_by(!!!data_grp, model, method) |>
     dplyr::summarize(npar = dplyr::n())
-  data_grp_vars <- sapply(object$data_group, rlang::as_label)
 
   # BIC requires knowing how many observations each group has
-  ll <- ll %>% dplyr::rowwise() %>%
+  ll <- ll |> dplyr::rowwise() |>
     dplyr::mutate(N_ROW = nrow(observations))
 
   # Combining log-likelihood table with parameters table
-  ll <- ll %>%
-    dplyr::select(!!!object$data_group,
+  ll <- ll |>
+    dplyr::select(!!!data_grp,
                   model, method,
                   log_likelihood,
-                  N_ROW) %>%
+                  N_ROW) |>
     dplyr::left_join(params_df, by = c(data_grp_vars, "model", "method"))
 
   # get number of parameters (excluding any constant, non-optimized parameters)
-
-  BIC <- ll %>%
-    dplyr::group_by(!!!object$data_group, model, method) %>%
-    dplyr::mutate(BIC = (log(N_ROW) * npar) - (2 * log_likelihood))
+  BIC <- ll |>
+    dplyr::group_by(!!!data_grp, model, method) |>
+    dplyr::mutate(BIC = (log(.data$N_ROW) * .data$npar) - (2 * .data$log_likelihood))
 
 
   return(BIC)
