@@ -14,7 +14,7 @@
 #'  plotted for these models. Default `NULL` to plot fits for all models in
 #'  `x$stat_model`.
 #' @param method Character: One or more of the [optimx::optimx()] methods used.
-#'  Default `NULL` to plot fits for all methods in `x$settings_optimx$method`.
+#'  Default `NULL` to plot fits for all methods in `x$pk_settings$optimx$method`.
 #' @param use_scale_conc Possible values: `TRUE`, `FALSE`, or a named list with
 #'  elements `dose_norm` and `log10_trans` which themselves should be either
 #'  `TRUE` or `FALSE`.  If `use_scale_conc = FALSE` (the default for this
@@ -94,18 +94,17 @@ plot.pk <- function(x,
     stop(attr(check, "msg"))
   }
 
-  if (is.null(model))
-    model <- names(x$stat_model)
-  if (is.null(method))
-    method <- x$settings_optimx$method
-  if (is.null(newdata))
-    newdata <- x$data
+  if (is.null(model)) model <- names(x$stat_model)
+  if (is.null(method)) method <- x$pk_settings$optimx$method
+  if (is.null(newdata)) newdata <- get_data.pk(x)
 
   newdata_ok <- check_newdata(
     newdata = newdata,
     olddata = x$data,
-    req_vars = c("Time", "Time.Units", "Conc.Units",
-                 "Dose", "Route", "Media"),
+    req_vars = c(
+      "Time", "Time.Units", "Conc.Units",
+      "Dose", "Route", "Media"
+    ),
     exclude = FALSE
   )
 
@@ -117,23 +116,22 @@ plot.pk <- function(x,
   conc_scale <- conc_scale_use(obj = x, use_scale_conc = use_scale_conc)
 
   if (drop_nonDetect %in% TRUE) {
-    newdata <- subset(newdata, Detect %in% TRUE)
+    newdata <- newdata[newdata$Detect %in% TRUE, ]
   }
 
-  newdata <- subset(newdata, exclude %in% FALSE)
+  newdata <- newdata[newdata$exclude %in% FALSE, ]
 
-  if (is.null(log10_C))
-    log10_C <- conc_scale$log10_trans
+  if (is.null(log10_C)) log10_C <- conc_scale$log10_trans
 
 
   if (is.null(fit_limits)) {
-    fit_limits <- c(2.25, 0.05)
+    fit_limits <- c(1.25, 0.05)
     if (log10_C) {
       fit_limits[1] <- 5
     }
   }
 
-  if (is.numeric(fit_limits) & length(fit_limits) <= 2) {
+  if (is.numeric(fit_limits) && length(fit_limits) <= 2) {
     limit_predicted <- TRUE
     if (log10_C) {
       if (length(fit_limits) == 1) {
@@ -147,47 +145,59 @@ plot.pk <- function(x,
       warning("No lower bound needed, Upper Bounds set to first value supplied.")
     }
   } else {
-    if (is.character(fit_limits) & (fit_limits == "none")) {
+    if (is.character(fit_limits) && (fit_limits == "none")) {
       limit_predicted <- FALSE
     } else {
-      stop(
+      cli::cli_abort(
         "fit_limits must be numeric vector of length 1 or 2. Set fit_limits = 'none' to prevent possible predicted data filtering."
       )
     }
   }
 
-
+  # Selecting variable used for time (either transformed or untransformed time)
   time_var <- ifelse(time_trans, as.name("Time_trans"), as.name("Time"))
 
   time_units_var <- ifelse(time_trans,
-                           as.name("Time_trans.Units"),
-                           as.name("Time.Units"))
+    as.name("Time_trans.Units"),
+    as.name("Time.Units")
+  )
 
-  common_vars <- ggplot2::vars(Time,
-                               Time.Units,
-                               Dose,
-                               Route,
-                               Media)
+  data_grp <- get_data_group.pk(x)
+  data_grp_vars <- get_data_group.pk(x, as_character = TRUE)
+
+  common_vars <- rlang::exprs(
+    Time,
+    Time.Units,
+    Dose,
+    Route,
+    Media
+  )
 
   if (time_trans) {
-    common_vars <- union(common_vars,
-                         ggplot2::vars(Time_trans, Time_trans.Units))
+    common_vars <- union(
+      common_vars,
+      rlang::exprs(Time_trans, Time_trans.Units)
+    )
   }
 
   obs_vars <- setdiff(
-    ggplot2::vars(
-    Conc,
-    Conc_SD,
-    Conc.Units,
-    Value,
-    Value.Units,
-    Detect,
-    exclude,
-    Conc_trans,
-    Conc_trans.Units,
-    Reference
-  ),
-  x$data_group)
+    rlang::exprs(
+      Conc,
+      Conc_SD, Conc.Units,
+      Value, Value.Units,
+      Detect, exclude,
+      Conc_trans, Conc_trans.Units,
+      Reference
+    ),
+    data_grp
+  )
+
+  name_subtitle <- FALSE
+  if ("Chemical_Name" %in% names(newdata) &&
+    !identical(newdata$Chemical, newdata$Chemical_Name)) {
+    obs_vars <- union(rlang::exprs(Chemical_Name), obs_vars)
+    name_subtitle <- TRUE
+  }
 
 
   # Default arguments and functions
@@ -199,9 +209,11 @@ plot.pk <- function(x,
     color = factor(Dose)
   )
 
-  plot_point_aes_default <- ggplot2::aes(fill = factor(Dose),
-                                         shape = Reference,
-                                         alpha = Detect)
+  plot_point_aes_default <- ggplot2::aes(
+    fill = factor(ifelse(Detect %in% "Detect", Dose, NA)),
+    shape = Reference
+  )
+
 
   plot_fit_aes_default <- ggplot2::aes(
     x = !!time_var,
@@ -220,29 +232,36 @@ plot.pk <- function(x,
   } else {
     facet_fun_default <- "facet_wrap"
     facet_fun_args_default <- list(ggplot2::vars(Route, Media, Dose),
-                                   scales = "free_y",
-                                   labeller = "label_both")
+      scales = "free_y",
+      labeller = "label_both"
+    )
   }
 
-  if (is.null(plot_data_aes))
+  if (is.null(plot_data_aes)) {
     plot_data_aes <- plot_data_aes_default
-  if (is.null(plot_point_aes))
+  }
+  if (is.null(plot_point_aes)) {
     plot_point_aes <- plot_point_aes_default
-  if (is.null(plot_fit_aes))
+  }
+  if (is.null(plot_fit_aes)) {
     plot_fit_aes <- plot_fit_aes_default
-  if (is.null(facet_fun))
+  }
+  if (is.null(facet_fun)) {
     facet_fun <- facet_fun_default
-  if (is.null(facet_fun_args))
+  }
+  if (is.null(facet_fun_args)) {
     facet_fun_args <- facet_fun_args_default
+  }
 
-  if (facet_fun %in% "none")
+  if (facet_fun %in% "none") {
     facet_fun <- NULL
+  }
 
   # I think ideally there should be required variables and
   # a way to ensure all the aes() variables get added
-  newdata <- newdata %>%
-    dplyr::select(!!!union(union(x$data_group, common_vars), obs_vars)) %>%
-    dplyr::rowwise() %>%
+  newdata <- newdata |>
+    dplyr::select(!!!union(union(data_grp, common_vars), obs_vars)) |>
+    dplyr::rowwise() |>
     # apply dose-norm if specified, but do not apply log10-trans even if specified
     # (if log10-trans specified, the y axis will be log10-scaled)
     dplyr::mutate(
@@ -250,151 +269,161 @@ plot.pk <- function(x,
       Conc_set_SD = ifelse(conc_scale$dose_norm, Conc_SD / Dose, Conc_SD),
       Detect = ifelse(Detect, "Detect", "Non-Detect"),
       Dose = Dose
-    ) %>%
-    dplyr::ungroup() %>%
-    dplyr::group_by(!!!x$data_group) %>%
+    ) |>
+    dplyr::ungroup() |>
+    dplyr::group_by(!!!data_grp) |>
     tidyr::nest(.key = "observations")
 
 
-  newdata <- newdata %>%
-    dplyr::mutate(observation_plot =
-                    purrr::map(observations, \(x) {
-                      # Need to write this into a mutate + map pattern function
-                      # initialize plot
-                      p <- ggplot(data = x, mapping = plot_data_aes) +
-                        geom_point(mapping = plot_point_aes, stroke = 1) + # plots points
-                        geom_errorbar(mapping = plot_data_aes)
+  newdata <- newdata |>
+    dplyr::mutate(
+      observation_plot =
+        purrr::map(observations, \(x) {
+          # Need to write this into a mutate + map pattern function
+          # initialize plot
+          p <- ggplot(data = x, mapping = plot_data_aes) +
+            geom_point(mapping = plot_point_aes, stroke = 1) + # plots points
+            geom_errorbar(mapping = plot_data_aes, na.rm = TRUE)
 
-                      t_units <- x %>%
-                        dplyr::pull(!!time_units_var) %>%
-                        unique()
+          t_units <- x |>
+            dplyr::pull(!!time_units_var) |>
+            unique()
 
-                      # if alpha = Detect then we have to do some trickery to implement that
-                      # that is the objective of plot_point_aes
-                      if (rlang::as_label(plot_point_aes$alpha) %in% "Detect") {
-                        # plot the data
-                        p <- p +
-                          geom_point()
-                        # plots here are un-filled points (only inherits color variable by default)
+          # if alpha = Detect then we have to do some trickery to implement that
+          # that is the objective of plot_point_aes
+          if (rlang::quo_get_expr(plot_point_aes$fill) == quote(
+            factor(ifelse(Detect %in% "Detect", Dose, NA)) # The default
+          )) {
+            if ("shape" %in% c(names(plot_data_aes), names(plot_point_aes))) {
+              # Ensure shapes can take both fill and color if alpha is set
+              p <- p +
+                scale_shape_manual(values = 21:25)
+            }
 
-                        if ("shape" %in% c(names(plot_data_aes), names(plot_point_aes))) {
-                          # Ensure shapes can take both fill and color if alpha is set
-                          p <- p +
-                            scale_shape_manual(values = 21:25)
-                        }
+            # get limits and breaks
+            # if there is an NA, include in breaks
+            if ("Non-Detect" %in% x$Detect) {
+              alpha_breaks <- max(x$Dose, na.rm = TRUE)
+              p <- p +
+                scale_fill_discrete(
+                  na.value = "transparent",
+                  breaks = alpha_breaks,
+                  labels = "Non-Detect",
+                  guide = guide_legend(
+                    title = NULL,
+                    order = 2,
+                    override.aes = list(shape = 21, fill = NA, color = "black", stroke = 1)
+                  )
+                )
+            } else {
+              p <- p +
+                guides(fill = "none")
+            }
+          }
 
-                        # set an alpha scale
-                        p <- p + scale_alpha_manual(
-                          values = c("Detect" = 1, "Non-Detect" = 0),
-                          breaks = c("Detect", "Non-Detect"),
-                          drop = FALSE,
-                          name = NULL
-                        )
+          p <- p +
+            do.call(facet_fun, args = facet_fun_args)
 
-                        # Need to check whether there are two values in Detect
-                        # some might be all Non-Detect or all Detect
-                        if (length(unique(x$Detect)) > 1) {
-                          alpha_fill <- c("black", NA)
-                        } else {
-                          alpha_fill <- ifelse(unique(x$Detect) == "Detect", "black", NA)
-                        }
-                        p <- p +
-                          guides(alpha = guide_legend(
-                            override.aes = list(
-                              shape = 21,
-                              color = "black",
-                              stroke = 1,
-                              fill = alpha_fill,
-                              alpha = 1
-                            ),
-                            order = 2
-                          ))
+          if (log10_C) {
+            p <- p + scale_y_continuous(trans = "log10", labels = scales::label_log())
+          }
 
-                      }
+          p <- p +
+            labs(
+              title = paste(!!!data_grp),
+              x = paste0("Time (", t_units, ")"),
+              y = ifelse(
+                conc_scale$dose_norm,
+                "Concentration/Dose",
+                "Concentration"
+              )
+            ) +
+            theme_bw() +
+            theme(
+              panel.border = element_rect(
+                color = "black",
+                fill = NA,
+                linewidth = 1
+              ),
+              plot.title = element_text(hjust = 0.5, face = "bold"),
+              strip.background = element_rect(
+                fill = "white",
+                color = "black",
+                size = 1
+              )
+            )
 
-                      p <- p +
-                        do.call(facet_fun, args = facet_fun_args)
+          if (limit_predicted && log10_C) {
+            p <- p + coord_cartesian(
+              ylim = c(fit_limits[2] * min(x$Conc_set), fit_limits[1] * max(x$Conc_set))
+            )
+          } else if (limit_predicted && !log10_C) {
+            p <- p + coord_cartesian(
+              ylim = c(0, fit_limits * max(x$Conc_set))
+            )
+          }
 
-                      if (log10_C) {
-                        p <- p + scale_y_continuous(trans = "log10", labels = scales::label_log())
-                      }
+          # Add name if not already Chemical
+          if (name_subtitle) {
+            p <- p +
+              labs(subtitle = unique(x$Chemical_Name)) +
+              theme(plot.subtitle = element_text(hjust = 0.5))
+          }
 
-                      p +
-                        labs(
-                          #title = paste(Chemical, Species),
-                          title = paste(!!!x$data_group),
-                          x = paste0("Time (", t_units, ")"),
-                          y = ifelse(
-                            conc_scale$dose_norm,
-                            "Concentration/Dose",
-                            "Concentration"
-                          )
-                        ) +
-                        theme_bw() +
-                        theme(
-                          panel.border = element_rect(
-                            color = "black",
-                            fill = NA,
-                            linewidth = 1
-                          ),
-                          plot.title = element_text(hjust = 0.5, face = "bold"),
-                          strip.background = element_rect(
-                            fill = "white",
-                            color = "black",
-                            size = 1
-                          )
-                        )
-
-
-
-                    }))
+          # Return value
+          p
+        })
+    )
 
   # For predictions, interpolate time
   if (get_status(obj = x) == 5) {
     interp_data <- newdata
 
-    interp_data <- interp_data %>%
+    interp_data <- interp_data |>
       dplyr::mutate(interpolated = purrr::map(observations, \(x) {
         # if needed and not present, add Time_trans.Units column
         if (time_trans %in% TRUE) {
           if (!("Time_trans.Units" %in% names(x))) {
-            x <- x %>%
+            x <- x |>
               dplyr::mutate(Time_trans.Units = Time.Units)
           }
 
-          x %>%
-            dplyr::select(!!!union(common_vars, obs_vars)) %>%
-            dplyr::group_by(Dose, Route, Media) %>%
-            dplyr::reframe(Time = max(Time), # Change to Time
-                           Time.Units, Time_trans.Units,
-                           Conc.Units) %>%
+          x <- x |>
+            dplyr::select(!!!union(common_vars, obs_vars)) |>
+            dplyr::group_by(Dose, Route, Media) |>
+            dplyr::reframe(
+              Time = max(Time), # Change to Time
+              Time.Units, Time_trans.Units,
+              Conc.Units
+            ) |>
             dplyr::mutate(
               maxTime = max(Time),
               Time.Units = unique(Time.Units),
               Time_trans.Units = unique(Time_trans.Units)
-            ) %>%
-            tidyr::uncount(n_interp) %>%
-            dplyr::group_by(Dose, Route, Media) %>%
-            dplyr::mutate(Time = (maxTime / (dplyr::n() - 1)) *
-                            (dplyr::row_number() - 1))
+            )
         } else if (time_trans %in% FALSE) {
-          x %>%
-            dplyr::select(!!!union(common_vars, obs_vars)) %>%
-            dplyr::group_by(Dose, Route, Media) %>%
-            dplyr::reframe(Time = max(Time), # Change to Time
-                           Time.Units, Conc.Units) %>%
-            dplyr::mutate(maxTime = max(Time),
-                          Time.Units = unique(Time.Units)) %>%
-            tidyr::uncount(n_interp) %>%
-            dplyr::group_by(Dose, Route, Media) %>%
-            dplyr::mutate(Time = (maxTime / (dplyr::n() - 1)) *
-                            (dplyr::row_number() - 1))
+          x <- x |>
+            dplyr::select(!!!union(common_vars, obs_vars)) |>
+            dplyr::group_by(Dose, Route, Media) |>
+            dplyr::reframe(
+              Time = max(Time), # Change to Time
+              Time.Units, Conc.Units
+            ) |>
+            dplyr::mutate(
+              maxTime = max(Time),
+              Time.Units = unique(Time.Units)
+            )
         }
-      }))
+        x |>
+          tidyr::uncount(n_interp) |>
+          dplyr::group_by(Dose, Route, Media) |>
+          dplyr::mutate(Time = (.data$maxTime / (dplyr::n() - 1)) *
+            (dplyr::row_number() - 1))
+      }, .progress = TRUE))
 
-    interp_data <- interp_data %>%
-      dplyr::select(!!!x$data_group, interpolated) %>%
-      tidyr::unnest(cols = c(interpolated)) %>%
+    interp_data <- interp_data |>
+      dplyr::select(!!!data_grp, c("interpolated")) |>
+      tidyr::unnest(cols = c("interpolated")) |>
       dplyr::ungroup()
 
 
@@ -415,97 +444,75 @@ plot.pk <- function(x,
     )
 
     if (best_fit %in% TRUE) {
-      interp_data <- dplyr::left_join(get_winning_model(obj = x), interp_data)
+      interp_data <- dplyr::left_join(
+        get_winning_model(obj = x),
+        interp_data
+      ) |>
+        suppressMessages()
     }
 
     # if plotting transformed time, then transform interpolated time points
     if (time_trans %in% TRUE) {
-      conversion_table <- time_conversions %>%
+      conversion_table <- time_conversions |>
         dplyr::filter(
-          TimeFrom %in% interp_data$Time.Units,
-          TimeTo %in% interp_data$Time_trans.Units
-        ) %>%
+          .data$TimeFrom %in% interp_data$Time.Units,
+          .data$TimeTo %in% interp_data$Time_trans.Units
+        ) |>
         dplyr::rename(Time.Units = "TimeFrom", Time_trans.Units = "TimeTo")
 
-      interp_data <- interp_data %>%
+      interp_data <- interp_data |>
         dplyr::left_join(conversion_table,
-                         by = dplyr::join_by(Time.Units, Time_trans.Units)) %>%
-        dplyr::mutate(Time_trans = Time * conversion) %>%
-        dplyr::select(!conversion)
+          by = dplyr::join_by(Time.Units, Time_trans.Units)
+        ) |>
+        dplyr::mutate(Time_trans = Time * .data$conversion) |>
+        dplyr::select(!c("conversion"))
     }
 
-
-
-
-    interp_data <- interp_data %>%
-      dplyr::group_by(!!!x$data_group) %>%
+    interp_data <- interp_data |>
+      dplyr::group_by(!!!data_grp) |>
       tidyr::nest(.key = "predicted")
 
-    newdata <- dplyr::left_join(newdata, interp_data)
+
+    newdata <- dplyr::left_join(newdata, interp_data,
+      by = c(data_grp_vars)
+    )
 
     # Need to check if predicted is NULL before filtering below
     # NULL predicted values will occur when there was no adequate fit for the model
 
-    if (limit_predicted %in% TRUE) {
-      if (log10_C %in% TRUE) {
-        newdata <- newdata %>%
-          dplyr::mutate(predicted = purrr::map2(observations, predicted, \(x, y) {
-            if (!is.null(y)) {
-              dplyr::filter(y,
-                            Conc_est <= (fit_limits[1] * max(x$Conc_set)),
-                            Conc_est >= (fit_limits[2] * min(x$Conc_set)))
-            } else {
-              message(paste(
-                Chemical, Species, "did not have adequate fit"
-              ))
-            }
 
-          }))
-      } else {
-        newdata <- newdata %>%
-          dplyr::mutate(predicted = purrr::map2(observations, predicted, \(x, y) {
-            if (!is.null(y)) {
-              dplyr::filter(y, Conc_est <= (fit_limits[1] * max(x$Conc_set)))
-            } else {
-              message(paste(
-                Chemical, Species, "did not have adequate fit"
-              ))
-            }
-          }))
-      }
-    }
-
-    newdata <- newdata %>%
-      dplyr::mutate(predicted_plot = purrr::map(predicted, \(x) {
+    newdata <- newdata |>
+      dplyr::mutate(predicted_plot = purrr::map(.data$predicted, \(x) {
         if (!is.null(x)) {
-        ggplot2::geom_line(data = x,
-                           mapping = plot_fit_aes,
-                           inherit.aes = FALSE)
+          ggplot2::geom_line(
+            data = x,
+            mapping = plot_fit_aes,
+            inherit.aes = FALSE
+          )
         } else {
           NULL
         }
-      })) %>%
+      })) |>
       dplyr::mutate(final_plot = purrr::map2(
-        observation_plot,
-        predicted_plot,
+        .data$observation_plot,
+        .data$predicted_plot,
         \(x, y) x + y +
           guides(
             color = guide_legend(title = "Dose", order = 1),
-            fill = "none",
             linetype = guide_legend(title = "Model & Method", order = 3),
-            shape = guide_legend(order = 4)
+            shape = guide_legend(order = 4, override.aes = list(fill = "black"))
           )
       ))
-
   } else {
-    newdata <- newdata %>%
+    newdata <- newdata |>
       dplyr::rename(final_plot = "observation_plot")
 
     message("Note that the final plots do not contain any fits")
   }
 
-  if (print_out)
+  if (print_out) {
     return(newdata$final_plot)
+  }
 
   return(newdata)
 }
